@@ -1,7 +1,10 @@
 #
-# $Id: net.sunrise.sh,v 1.2 2001/10/14 00:09:35 mcr Exp $
+# $Id: net.sunrise.sh,v 1.3 2002/06/18 19:12:31 mcr Exp $
 #
-if [ -n "$UML_private_CTL" ]
+if [ -n "$UML_east_CTL" ]
+then
+    net_eth0="eth0=daemon,10:00:00:dc:bc:01,unix,$UML_east_CTL,$UML_east_DATA";
+elif [ -n "$UML_private_CTL" ]
 then
     net_eth0="eth0=daemon,10:00:00:dc:bc:01,unix,$UML_private_CTL,$UML_private_DATA";
 else
